From d4a5256a264efd2185e7c747ca900af38ce0d34d Mon Sep 17 00:00:00 2001
From: Joel Sherrill <joel@rtems.org>
Date: Wed, 14 Aug 2019 11:24:37 +0100
Subject: [PATCH] fenv: Include documentation in generated .info file

---
 newlib/libm/fenv/Makefile.am |  2 +-
 newlib/libm/fenv/Makefile.in |  2 +-
 newlib/libm/fenv/fenv.tex    | 45 ++++++++++++++++++++++++++++++++++++
 newlib/libm/libm.in.xml      |  1 +
 newlib/libm/libm.texinfo     |  1 +
 5 files changed, 49 insertions(+), 2 deletions(-)
 create mode 100644 newlib/libm/fenv/fenv.tex

diff --git a/newlib/libm/fenv/Makefile.am b/newlib/libm/fenv/Makefile.am
index 8d7a70273..ebe03970b 100644
--- a/newlib/libm/fenv/Makefile.am
+++ b/newlib/libm/fenv/Makefile.am
@@ -29,7 +29,7 @@ CHEWOUT_FILES =	feclearexcept.def fegetenv.def \
 	feraiseexcept.def fesetenv.def fesetexceptflag.def fesetround.def \
 	fetestexcept.def feupdateenv.def
 
-CHAPTERS =
+CHAPTERS = fenv.tex
 
 # A partial dependency list.
 
diff --git a/newlib/libm/fenv/Makefile.in b/newlib/libm/fenv/Makefile.in
index c8760b2a7..b2adb823a 100644
--- a/newlib/libm/fenv/Makefile.in
+++ b/newlib/libm/fenv/Makefile.in
@@ -271,7 +271,7 @@ CHEWOUT_FILES = feclearexcept.def fegetenv.def \
 	feraiseexcept.def fesetenv.def fesetexceptflag.def fesetround.def \
 	fetestexcept.def feupdateenv.def
 
-CHAPTERS =
+CHAPTERS = fenv.tex
 all: all-am
 
 .SUFFIXES:
diff --git a/newlib/libm/fenv/fenv.tex b/newlib/libm/fenv/fenv.tex
new file mode 100644
index 000000000..3b76003d3
--- /dev/null
+++ b/newlib/libm/fenv/fenv.tex
@@ -0,0 +1,45 @@
+@node Fenv
+@chapter Floating-Point Environment (@file{fenv.h})
+
+This chapter groups the methods used to manipulate the floating-point
+status flags. Floating-point operations modify the floating-point
+status flags to indicate abnormal result information.
+
+The implementation of these methods is architecture specific.
+
+@menu
+* feclearexcept::		Clear floating-point exception
+* fegetenv::		Get current floating-point environment
+* fegetexceptflag::	Get floating-point status flags
+* fegetround::		Get current rounding direction
+* feholdexcept::		Save current floating-point environment
+* feraiseexcept::		Raise floating-point exception
+* fesetenv::		Set current floating-point environment
+* fesetexceptflag::	Set floating-point status flags
+* fesetround::		Set current rounding direction
+* fetestexcept::		Test floating-point exception flags
+* feupdateenv::		Update current floating-point environment
+@end menu
+
+@page
+@include fenv/feclearexcept.def
+@page
+@include fenv/fegetenv.def
+@page
+@include fenv/fegetexceptflag.def
+@page
+@include fenv/fegetround.def
+@page
+@include fenv/feholdexcept.def
+@page
+@include fenv/feraiseexcept.def
+@page
+@include fenv/fesetenv.def
+@page
+@include fenv/fesetexceptflag.def
+@page
+@include fenv/fesetround.def
+@page
+@include fenv/fetestexcept.def
+@page
+@include fenv/feupdateenv.def
diff --git a/newlib/libm/libm.in.xml b/newlib/libm/libm.in.xml
index dea8a0f6c..f60030478 100644
--- a/newlib/libm/libm.in.xml
+++ b/newlib/libm/libm.in.xml
@@ -7,6 +7,7 @@
 
   <xi:include href="complex.xml"/>
   <xi:include href="math.xml"/>
+  <xi:include href="fenv.xml"/>
 
   <!-- processing should insert index here -->
   <index/>
diff --git a/newlib/libm/libm.texinfo b/newlib/libm/libm.texinfo
index a579a1743..779615d32 100644
--- a/newlib/libm/libm.texinfo
+++ b/newlib/libm/libm.texinfo
@@ -94,6 +94,7 @@ into another language, under the above conditions for modified versions.
 @menu
 * Math::           The mathematical functions (`math.h').
 * Complex::        The mathematical complex functions (`complex.h').
+* Fenv::           The floating point environment functions ('fenv.h').
 * Reentrancy::     The functions in libm are not reentrant by default.
 * Long Double Functions:: The long double function support of libm.
 * Document Index::
-- 
2.21.0

